Module client

Module client 

Bitwarden SDK Client

Modules

client_settings
encryption_settings
internal
login_method
test_accounts

Structs

ApiConfigurations
Client
The main struct to interact with the Bitwarden SDK.
ClientSettings
Basic client behavior settings. These settings specify the various targets and behavior of the Bitwarden Client. They are optional and uneditable once the client is initialized.

Enums

DeviceType