Bitwarden SDK Client
Modules
Structs
- ApiConfigurations
- Client
- The main struct to interact with the Bitwarden SDK.
- Client
Settings - Basic client behavior settings. These settings specify the various targets and behavior of the Bitwarden Client. They are optional and uneditable once the client is initialized.